@@ -2,6 +2,7 @@ import urllib
 import requests
 import json
 import logging
+
 logger = logging.getLogger(__name__)
 import webbrowser
 
@@ -10,6 +11,7 @@ import numpy as np
 import datetime
 import pandas as pd
 
+
 class BaseEncoder(json.JSONEncoder):
     def default(self, obj):
         if isinstance(obj, np.ndarray) or isinstance(obj, pd.Series):
@@ -104,13 +106,13 @@ client=CAVEclient(server_address="{urlp.scheme +"://"+ urlp.netloc}")"""
         )
 
 
-def _api_versions(server_name, server_address, endpoints_common, auth_header):
+def _api_versions(server_name, server_address, endpoints_common, auth_header, verify=True):
     """Asks a server what API versions are available, if possible"""
     url_mapping = {server_name: server_address}
     url_base = endpoints_common.get("get_api_versions", None)
     if url_base is not None:
         url = url_base.format_map(url_mapping)
-        response = requests.get(url, headers=auth_header)
+        response = requests.get(url, headers=auth_header, verify=verify)
         _raise_for_status(response)
         return response.json()
     else:
@@ -124,12 +126,14 @@ def _api_endpoints(
     endpoints_common,
     endpoint_versions,
     auth_header,
+    fallback_version=None,
+    verify=True,
 ):
     "Gets the latest client API version"
     if api_version == "latest":
         try:
             avail_vs_server = _api_versions(
-                server_name, server_address, endpoints_common, auth_header
+                server_name, server_address, endpoints_common, auth_header, verify=verify
             )
             avail_vs_server = set(avail_vs_server)
         except:
@@ -138,7 +142,10 @@ def _api_endpoints(
         avail_vs_client = set(endpoint_versions.keys())
 
         if avail_vs_server is None:
-            api_version = max(avail_vs_client)
+            if fallback_version is None:
+                api_version = max(avail_vs_client)
+            else:
+                api_version = fallback_version
         else:
             api_version = max(avail_vs_client.intersection(avail_vs_server))
 
